@@ -5,13 +5,16 @@ startme() {
     if [ ! -f sp_conf.py ] ; then
         cp sp_conf.py.example sp_conf.py
     fi
-    ../../tools/make_metadata.py sp_conf > sp.xml
+    if [ ! -f service_conf.py ] ; then
+        cp service_conf.py.example service_conf.py
+    fi
+    ../../src/saml2/tools/make_metadata.py sp_conf > sp.xml
 
     cd ../idp2
     if [ ! -f idp_conf.py ] ; then
         cp idp_conf.py.example idp_conf.py
     fi
-    ../../tools/make_metadata.py idp_conf > idp.xml
+    ../../src/saml2/tools/make_metadata.py idp_conf > idp.xml
 
     cd ../sp-wsgi
     ./sp.py sp_conf &
